@@ -47,7 +47,7 @@ def run():
     """, factory=True)
 
 
-    # Change this macro into a value so we wont have problems when SIP takes its
+    # Change this macro into a value so we won't have problems when SIP takes its
     # address
     module.addCppCode("""\
     #undef wxTransparentColour
@@ -82,7 +82,7 @@ def run():
     c.addProperty('blue Blue')
     c.addProperty('alpha Alpha')
 
-    c.find('GetPixel').ignore()  # We need to add a typcast
+    c.find('GetPixel').ignore()  # We need to add a typecast
     c.addCppMethod('wxIntPtr*', 'GetPixel', '()', """\
         #if defined(__WXGTK3__) || defined(__WXOSX__)
             return new wxIntPtr(0);
@@ -192,7 +192,9 @@ def run():
     #     String with color name or #RRGGBB or #RRGGBBAA format
     #     None  (converts to wxNullColour)
     c.allowNone = True
-    c.convertFromPyObject = """\
+    c.convertFromPyObject = tools.AutoConversionInfo(
+        ('wx.Colour', '_ThreeInts', '_FourInts', 'str', 'None'),
+        """\
         // is it just a typecheck?
         if (!sipIsErr) {
             if (sipPy == Py_None)
@@ -273,7 +275,7 @@ def run():
         *sipCppPtr = reinterpret_cast<wxColour*>(sipConvertToType(
             sipPy, sipType_wxColour, sipTransferObj, SIP_NO_CONVERTORS, 0, sipIsErr));
         return 0; // not a new instance
-    """
+    """)
 
     module.addPyCode('NamedColour = wx.deprecated(Colour, "Use Colour instead.")')
 
