@@ -24,6 +24,7 @@ ITEMS  = [
             'wxDataViewItem',
             'wxDataViewItemAttr',
             'wxDataViewIconText',
+            'wxDataViewCheckIconText',
             'wxDataViewModelNotifier',
 
             'wxDataViewModel',
@@ -82,7 +83,7 @@ def run():
 
     c.addCppMethod('int', '__nonzero__', '()', "return self->IsOk();")
     c.addCppMethod('int', '__bool__', '()', "return self->IsOk();")
-    c.addCppMethod('long', '__hash__', '()', "return (long)self->GetID();")
+    c.addCppMethod('long', '__hash__', '()', "return (long)(intptr_t)self->GetID();")
 
     c.addCppMethod('bool', '__eq__', '(wxDataViewItem* other)',
                    "return other ? (self->GetID() == other->GetID()) : false;")
@@ -125,7 +126,7 @@ def run():
 
             By default a regular dictionary is used to implement the ID to object
             mapping. Optionally a WeakValueDictionary can be useful when there will be
-            a high turnover of objects and mantaining an extra reference to the
+            a high turnover of objects and maintaining an extra reference to the
             objects would be unwise.  If weak references are used then the objects
             associated with data items must be weak-referenceable.  (Things like
             stock lists and dictionaries are not.)  See :meth:`UseWeakRefs`.
@@ -308,6 +309,7 @@ def run():
     # them in all these classes
     for name in [ 'wxDataViewTextRenderer',
                   'wxDataViewIconTextRenderer',
+                  'wxDataViewCheckIconTextRenderer',
                   'wxDataViewProgressRenderer',
                   'wxDataViewSpinRenderer',
                   'wxDataViewToggleRenderer',
@@ -344,7 +346,7 @@ def run():
     c.addItem(etgtools.WigCode("""\
         virtual void SetTitle(const wxString& title);
         virtual wxString GetTitle() const;
-        virtual void SetBitmap(const wxBitmap& bitmap);
+        virtual void SetBitmap(const wxBitmapBundle& bitmap);
         virtual wxBitmap GetBitmap() const;
         virtual void SetWidth(int width);
         virtual int GetWidth() const;
