@@ -19,15 +19,12 @@
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-    #pragma hdrstop
-#endif
 
 #ifndef WX_PRECOMP
     #include "wx/dcclient.h"
     #include "wx/settings.h"
     #include "wx/brush.h"
-    #include "wx/combobox.h"
+    #include "wx/choice.h"
     #include "wx/listbox.h"
     #include "wx/stattext.h"
     #include "wx/textctrl.h"
@@ -48,7 +45,7 @@
 
 #ifdef wxHAS_NATIVE_CALENDARCTRL
 
-wxIMPLEMENT_DYNAMIC_CLASS_XTI(wxGenericCalendarCtrl, wxControl, "wx/calctrl.h");
+wxIMPLEMENT_DYNAMIC_CLASS(wxGenericCalendarCtrl, wxControl);
 
 #endif
 
@@ -130,7 +127,7 @@ wxGenericCalendarCtrl::wxGenericCalendarCtrl(wxWindow *parent,
 
 void wxGenericCalendarCtrl::Init()
 {
-    m_comboMonth = NULL;
+    m_choiceMonth = NULL;
     m_spinYear = NULL;
     m_staticYear = NULL;
     m_staticMonth = NULL;
@@ -230,7 +227,7 @@ wxGenericCalendarCtrl::~wxGenericCalendarCtrl()
 
     if ( !HasFlag(wxCAL_SEQUENTIAL_MONTH_SELECTION) )
     {
-        delete m_comboMonth;
+        delete m_choiceMonth;
         delete m_staticMonth;
         delete m_spinYear;
         delete m_staticYear;
@@ -253,32 +250,30 @@ void wxGenericCalendarCtrl::SetWindowStyleFlag(long style)
 }
 
 // ----------------------------------------------------------------------------
-// Create the wxComboBox and wxSpinCtrl
+// Create the wxChoice and wxSpinCtrl
 // ----------------------------------------------------------------------------
 
 void wxGenericCalendarCtrl::CreateMonthComboBox()
 {
-    m_comboMonth = new wxComboBox(GetParent(), wxID_ANY,
-                                  wxEmptyString,
+    m_choiceMonth = new wxChoice(GetParent(), wxID_ANY,
                                   wxDefaultPosition,
                                   wxDefaultSize,
-                                  0, NULL,
-                                  wxCB_READONLY | wxCLIP_SIBLINGS);
+                                  0, NULL);
 
     wxDateTime::Month m;
     for ( m = wxDateTime::Jan; m < wxDateTime::Inv_Month; wxNextMonth(m) )
     {
-        m_comboMonth->Append(wxDateTime::GetMonthName(m));
+        m_choiceMonth->Append(wxDateTime::GetMonthName(m));
     }
 
-    m_comboMonth->SetSelection(GetDate().GetMonth());
-    m_comboMonth->SetSize(wxDefaultCoord,
+    m_choiceMonth->SetSelection(GetDate().GetMonth());
+    m_choiceMonth->SetSize(wxDefaultCoord,
                           wxDefaultCoord,
                           wxDefaultCoord,
                           wxDefaultCoord,
                           wxSIZE_AUTO_WIDTH|wxSIZE_AUTO_HEIGHT);
 
-    m_comboMonth->Bind(wxEVT_COMBOBOX, &wxGenericCalendarCtrl::OnMonthChange, this);
+    m_choiceMonth->Bind(wxEVT_CHOICE, &wxGenericCalendarCtrl::OnMonthChange, this);
 }
 
 void wxGenericCalendarCtrl::CreateYearSpinCtrl()
@@ -304,14 +299,14 @@ bool wxGenericCalendarCtrl::Destroy()
         m_staticYear->Destroy();
     if ( m_spinYear )
         m_spinYear->Destroy();
-    if ( m_comboMonth )
-        m_comboMonth->Destroy();
+    if ( m_choiceMonth )
+        m_choiceMonth->Destroy();
     if ( m_staticMonth )
         m_staticMonth->Destroy();
 
     m_staticYear = NULL;
     m_spinYear = NULL;
-    m_comboMonth = NULL;
+    m_choiceMonth = NULL;
     m_staticMonth = NULL;
 
     return wxControl::Destroy();
@@ -362,7 +357,7 @@ void wxGenericCalendarCtrl::ShowCurrentControls()
     {
         if ( AllowMonthChange() )
         {
-            m_comboMonth->Show();
+            m_choiceMonth->Show();
             m_staticMonth->Hide();
 
             if ( AllowYearChange() )
@@ -376,7 +371,7 @@ void wxGenericCalendarCtrl::ShowCurrentControls()
         }
         else
         {
-            m_comboMonth->Hide();
+            m_choiceMonth->Hide();
             m_staticMonth->Show();
         }
 
@@ -389,7 +384,7 @@ void wxGenericCalendarCtrl::ShowCurrentControls()
 
 wxControl *wxGenericCalendarCtrl::GetMonthControl() const
 {
-    return AllowMonthChange() ? (wxControl *)m_comboMonth : (wxControl *)m_staticMonth;
+    return AllowMonthChange() ? (wxControl *)m_choiceMonth : (wxControl *)m_staticMonth;
 }
 
 wxControl *wxGenericCalendarCtrl::GetYearControl() const
@@ -458,7 +453,7 @@ bool wxGenericCalendarCtrl::SetDate(const wxDateTime& date)
                 if ( !(GetWindowStyle() & wxCAL_SEQUENTIAL_MONTH_SELECTION) )
                 {
                     // update the controls
-                    m_comboMonth->SetSelection(m_date.GetMonth());
+                    m_choiceMonth->SetSelection(m_date.GetMonth());
 
                     if ( AllowYearChange() )
                     {
@@ -671,15 +666,15 @@ size_t wxGenericCalendarCtrl::GetWeek(const wxDateTime& date) const
 // ----------------------------------------------------------------------------
 
 // this is a composite control and it must arrange its parts each time its
-// size or position changes: the combobox and spinctrl are along the top of
+// size or position changes: the choice and spinctrl are along the top of
 // the available area and the calendar takes up the rest of the space
 
-// the static controls are supposed to be always smaller than combo/spin so we
+// the static controls are supposed to be always smaller than choice/spin so we
 // always use the latter for size calculations and position the static to take
 // the same space
 
 // the constants used for the layout
-#define VERT_MARGIN    5           // distance between combo and calendar
+#define VERT_MARGIN    5           // distance between choice and calendar
 #define HORZ_MARGIN    5           //                            spin
 
 wxSize wxGenericCalendarCtrl::DoGetBestSize() const
@@ -692,12 +687,13 @@ wxSize wxGenericCalendarCtrl::DoGetBestSize() const
 
     if ( !HasFlag(wxCAL_SEQUENTIAL_MONTH_SELECTION) )
     {
-        const wxSize bestSizeCombo = m_comboMonth->GetBestSize();
+        const wxSize bestSizeChoice = m_choiceMonth->GetBestSize();
+        const wxSize bestSizeSpin = m_spinYear->GetBestSize();
 
-        height += wxMax(bestSizeCombo.y, m_spinYear->GetBestSize().y)
+        height += wxMax(bestSizeChoice.y, bestSizeSpin.y)
                     + VERT_MARGIN;
 
-        wxCoord w2 = bestSizeCombo.x + HORZ_MARGIN + GetCharWidth()*8;
+        wxCoord w2 = bestSizeChoice.x + HORZ_MARGIN + bestSizeSpin.x;
         if ( width < w2 )
             width = w2;
     }
@@ -717,16 +713,16 @@ void wxGenericCalendarCtrl::DoMoveWindow(int x, int y, int width, int height)
 
     if ( !HasFlag(wxCAL_SEQUENTIAL_MONTH_SELECTION) && m_staticMonth )
     {
-        wxSize sizeCombo = m_comboMonth->GetEffectiveMinSize();
+        wxSize sizeChoice = m_choiceMonth->GetEffectiveMinSize();
         wxSize sizeStatic = m_staticMonth->GetSize();
         wxSize sizeSpin = m_spinYear->GetSize();
 
-        int maxHeight = wxMax(sizeSpin.y, sizeCombo.y);
+        int maxHeight = wxMax(sizeSpin.y, sizeChoice.y);
         int dy = (maxHeight - sizeStatic.y) / 2;
-        m_comboMonth->Move(x, y + (maxHeight - sizeCombo.y)/2);
-        m_staticMonth->SetSize(x, y + dy, sizeCombo.x, -1);
+        m_choiceMonth->Move(x, y + (maxHeight - sizeChoice.y)/2);
+        m_staticMonth->SetSize(x, y + dy, sizeChoice.x, -1);
 
-        int xDiff = sizeCombo.x + HORZ_MARGIN;
+        int xDiff = sizeChoice.x + HORZ_MARGIN;
 
         m_spinYear->SetSize(x + xDiff, y + (maxHeight - sizeSpin.y)/2, width - xDiff, maxHeight);
         m_staticYear->SetSize(x + xDiff, y + dy, width - xDiff, sizeStatic.y);
@@ -904,8 +900,6 @@ void wxGenericCalendarCtrl::OnPaint(wxPaintEvent& WXUNUSED(event))
         }
     }
 
-    // then the calendar itself
-    dc.SetTextForeground(*wxBLACK);
     //dc.SetFont(*wxNORMAL_FONT);
 
     y += m_heightRow;
@@ -913,6 +907,7 @@ void wxGenericCalendarCtrl::OnPaint(wxPaintEvent& WXUNUSED(event))
     // draw column with calendar week nr
     if ( HasFlag( wxCAL_SHOW_WEEK_NUMBERS ) && IsExposed( 0, y, m_calendarWeekWidth, m_heightRow * 6 ))
     {
+        dc.SetTextForeground(*wxBLACK);
         dc.SetBackgroundMode(wxBRUSHSTYLE_TRANSPARENT);
         dc.SetBrush(wxBrush(m_colHeaderBg, wxBRUSHSTYLE_SOLID));
         dc.SetPen(wxPen(m_colHeaderBg, 1, wxPENSTYLE_SOLID));
@@ -927,6 +922,9 @@ void wxGenericCalendarCtrl::OnPaint(wxPaintEvent& WXUNUSED(event))
         }
     }
 
+    // then the calendar itself
+    dc.SetTextForeground(GetForegroundColour());
+
     wxDateTime date = GetStartDate();
 
 #if DEBUG_PAINT
@@ -1567,7 +1565,7 @@ void wxGenericCalendarCtrl::OnMonthChange(wxCommandEvent& event)
     {
         // The date must have been changed to ensure it's in valid range,
         // reflect this in the month choice control.
-        m_comboMonth->SetSelection(dt.GetMonth());
+        m_choiceMonth->SetSelection(dt.GetMonth());
     }
 
     SetDateAndNotify(dt);
